from distutils.core import setup
setup(
  name = 'introduction2343',
  packages = ['package'], # this must be the same as the name above
  version = '0.1',
  description = 'A random test lib',
  author = 'Edgar Josue',
  author_email = 'antitronic67@gmail.com',
  url = 'https://github.com/peterldowns/mypackage', # use the URL to the github repo
  download_url = 'https://github.com/peterldowns/mypackage/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['testing', 'logging', 'example'], # arbitrary keywords
  classifiers = [],
)